@@ -200,17 +200,21 @@ namespace PodSleuth.HalFrontend
         
         private static string GetProductionInfo(Hal.Volume volume)
         {
-            string factory_id = volume[HalNamespace + "ipod.production.factory_id"];
-            int year = volume.GetPropertyInteger(HalNamespace + "ipod.production.year");
-            int week = volume.GetPropertyInteger(HalNamespace + "ipod.production.week");
-            int number = volume.GetPropertyInteger(HalNamespace + "ipod.production.number");
-            
-            CultureInfo culture = CultureInfo.CurrentCulture;
-            DateTime production_date = culture.Calendar.AddWeeks(new DateTime(year, 1, 1), week);
-            
-            return String.Format("{0} in {1}, {2} from factory {3}",
-                number, culture.DateTimeFormat.GetMonthName(production_date.Month), 
-                year, factory_id);
+            try {
+                string factory_id = volume[HalNamespace + "ipod.production.factory_id"];
+                int year = volume.GetPropertyInteger(HalNamespace + "ipod.production.year");
+                int week = volume.GetPropertyInteger(HalNamespace + "ipod.production.week");
+                int number = volume.GetPropertyInteger(HalNamespace + "ipod.production.number");
+                
+                CultureInfo culture = CultureInfo.CurrentCulture;
+                DateTime production_date = culture.Calendar.AddWeeks(new DateTime(year, 1, 1), week);
+                
+                return String.Format("{0} in {1}, {2} from factory {3}",
+                    number, culture.DateTimeFormat.GetMonthName(production_date.Month), 
+                    year, factory_id);
+            } catch (Exception) {
+                return "Unknown";
+            }
         }
         
         private static void DumpSleuthableIpod(Hal.Volume volume)
