@@ -157,6 +157,9 @@ namespace PodSleuth.HalFrontend
                 
             hal_device.SetPropertyString("info.icon_name", pod_device.ModelInformation.IconName);
             hal_device.Parent.SetPropertyString("info.icon_name", pod_device.ModelInformation.IconName);
+
+            hal_device.SetPropertyString("info.desktop.icon", pod_device.ModelInformation.IconName);
+            hal_device.Parent.SetPropertyString("info.desktop.icon", pod_device.ModelInformation.IconName);
         }
     }
 }
