@@ -13,6 +13,7 @@ namespace PodSleuth.ModelData
         Green,
         Pink,
         Gold,
-        Purple
+        Purple,
+        Yellow
     }
 }
